<div dir="rtl">

# kenar-api
## درباره
این کتابخانه برای استفاده ی راحت‌تر و سریع‌تر از سرویس های کنار دیوار توسعه داده شده است.
>توجه: برای استفاده از این کتابخانه باید نیازمند نسخه ی پایتون بالاتر از 3.10 هستید. 

## ویژگی های اصلی
* تولید آدرس های oauth برای دریافت دسترسی ها از کاربر
* امکان ارسال پیام در چت دیوار
* امکان درج افزونه در آگهی های دیوار

## نحوه ی نصب 
برای این منظور میتوانید از پکیج منیجر [pip](https://pip.pypa.io/en/stable/) استفاده کنید

<div dir="ltr">

```bash
pip install Kenar
```
</div>

## پیشنهادات برای بهبود
پذیرای هر گونه پیشنهادات شما برای بهتر کردن این کتاب‌خانه هستیم. در قسمت issues پروژه میتوانید مسائل خود را با ما مطرح کنید.

## ادرس پنل توسعه دهندگان
[کنار دیوار](divar.ir/kenar)

</div>